@@ -11,9 +11,15 @@
 # COMMON REGISTRY
 ###########################################################################
 
-#' @import pkgmaker
 #' @import registry
-nmfRegistry <- function(...) pkgmaker::packageRegistry(...)
+nmfRegistry <- function(...) packageRegistry(...)
+
+# Returns the names of all the packages that contibute to all or a given
+# package's primary registry  
+registryContributors <- function(package, regname = NULL){
+    regs <- packageRegistries(regname = regname, package = package, primary = TRUE)
+    if( length(regs) ) unique(names(unlist(lapply(paste0(package, '::', regs), packageRegistries))))
+}
 
 ###% Return a method stored in the NMF registry.
 ###% 
@@ -27,12 +33,11 @@ nmfRegistry <- function(...) pkgmaker::packageRegistry(...)
 nmfGet <- function(regname, name=NULL, ...){
 	
 	# retrieve from the given package's sub-registry
-	pkgmaker::pkgreg_fetch(regname, key=name, ...)
+	pkgreg_fetch(regname, key=name, ...)
 	
 }
 
 ###% Register a NMF method so that it is accessible via the common interface defined by the \code{nmf} function.
-###% TODO: rewrite the doc (obsolete)
 ###% @param method an NMFStrategy object or a function that defines the method
 ###% @param key a non-empty character string that will be used as an identifier to access the method
 ###% @param overwrite a boolean that specify if an existing method (i.e. with exactly the same \code{key}) should be overwritten or not.
